# WARNING: This package is synced with FC
%global apiversion	0.1
%define major	1
%define libname	%mklibname cdr %{apiversion} %{major}
%define libdev	%mklibname cdr -d

Name:		libcdr
Version:	0.1.8
Release:	%mkrel 3
Summary:	A library for import of CorelDRAW drawings
Group:		System/Libraries
# the only Public Domain source is src/lib/CDRColorProfiles.h
License:	MPLv2.0 and Public Domain
URL:		https://wiki.documentfoundation.org/DLP/Libraries/libcdr
Source:		https://dev-www.libreoffice.org/src/%{name}/%{name}-%{version}.tar.xz

BuildRequires:	boost-devel
BuildRequires:	doxygen
BuildRequires:	gcc-c++
BuildRequires:	help2man
BuildRequires:	make
BuildRequires:	pkgconfig(cppunit)
BuildRequires:	pkgconfig(icu-i18n)
BuildRequires:	pkgconfig(lcms2)
BuildRequires:	pkgconfig(librevenge-0.0)
BuildRequires:	pkgconfig(librevenge-generators-0.0)
BuildRequires:	pkgconfig(librevenge-stream-0.0)
BuildRequires:	pkgconfig(zlib)

%description
Libcdr is library providing ability to interpret and import CorelDRAW
drawings into various applications. You can find it being used in
libreoffice.

%package -n %{libname}
Summary:	A library providing ability to interpret and import CorelDRAW drawings
Group:		System/Libraries

%description -n %{libname}
Libcdr is library providing ability to interpret and import CorelDRAW
drawings into various applications. You can find it being used in
libreoffice.

%package -n %{libdev}
Summary:	Development files for %{name}
Group:		Development/C
Requires:	%{libname} = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}

%description -n %{libdev}
This package contains libraries and header files for developing applications
that use %{name}.

%package doc
Summary:	Documentation of %{name} API
Group:		Documentation
BuildArch:	noarch

%description doc
The %{name}-doc package contains documentation files for %{name}.

%package tools
Summary:	Tools to transform CorelDRAW drawings into other formats
Group:		Graphics/Utilities

%description tools
Tools to transform CorelDRAW drawings into other formats.
Currently supported: XHTML, text, raw.

%prep
%setup -q

%build
%configure --disable-silent-rules --disable-static --disable-werror
sed -i \
    -e 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' \
    -e 's|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' \
    libtool
%make_build


%install
%make_install

# rhbz#1001251 we install API docs directly from build
rm -rf %{buildroot}%{_docdir}/%{name}

# generate and install man pages
export LD_LIBRARY_PATH=%{buildroot}%{_libdir}${LD_LIBRARY_PATH:+:${LD_LIBRARY_PATH}}
for tool in cdr2raw cmx2raw cdr2xhtml cmx2xhtml cdr2text cmx2text; do
    help2man -N -S '%{name} %{version}' -o ${tool}.1 %{buildroot}%{_bindir}/${tool}
done
mkdir -p %{buildroot}/%{_mandir}/man1
install -m 0644 cdr2*.1 cmx2*.1 %{buildroot}%{_mandir}/man1

%check
export LD_LIBRARY_PATH=%{buildroot}%{_libdir}${LD_LIBRARY_PATH:+:${LD_LIBRARY_PATH}}
make check

%files -n %{libname}
%doc AUTHORS ChangeLog README
%license COPYING.MPL
%{_libdir}/%{name}-%{apiversion}.so.%{major}{,.*}

%files -n %{libdev}
%{_includedir}/%{name}-%{apiversion}/
%{_libdir}/%{name}-%{apiversion}.so
%{_libdir}/pkgconfig/%{name}-%{apiversion}.pc

%files doc
%license COPYING.MPL
%doc docs/doxygen/html

%files tools
%{_bindir}/cdr2raw
%{_bindir}/cdr2text
%{_bindir}/cdr2xhtml
%{_bindir}/cmx2raw
%{_bindir}/cmx2text
%{_bindir}/cmx2xhtml
%{_mandir}/man1/cdr2raw.1*
%{_mandir}/man1/cdr2text.1*
%{_mandir}/man1/cdr2xhtml.1*
%{_mandir}/man1/cmx2raw.1*
%{_mandir}/man1/cmx2text.1*
%{_mandir}/man1/cmx2xhtml.1*


%changelog
* Tue Jul 01 2025 umeabot <umeabot> 0.1.8-3.mga10
+ Revision: 2233778
- Mageia 10 Mass Rebuild

* Sun Jan 12 2025 wally <wally> 0.1.8-2.mga10
+ Revision: 2138374
- rebuild for icu 76.1

* Mon Dec 30 2024 daviddavid <daviddavid> 0.1.8-1.mga10
+ Revision: 2131645
- new version: 0.1.8

* Tue Sep 26 2023 tv <tv> 0.1.7-6.mga10
+ Revision: 1991088
- Rebuild for icu-73

* Sat Jan 07 2023 squidf <squidf> 0.1.7-5.mga9
+ Revision: 1931134
- Mass rebuild for icu 72.1

* Sat Jun 18 2022 squidf <squidf> 0.1.7-4.mga9
+ Revision: 1864864
- rebuild for icu 71.1

* Tue Mar 29 2022 umeabot <umeabot> 0.1.7-3.mga9
+ Revision: 1831236
- Mageia 9 Mass Rebuild

* Tue Aug 03 2021 luigiwalser <luigiwalser> 0.1.7-2.mga9
+ Revision: 1738936
- rebuild for icu

* Tue Mar 30 2021 tv <tv> 0.1.7-1.mga9
+ Revision: 1711889
- 0.1.7

* Wed Dec 02 2020 luigiwalser <luigiwalser> 0.1.6-6.mga8
+ Revision: 1651650
- rebuild for missing signature

* Mon Nov 30 2020 luigiwalser <luigiwalser> 0.1.6-5.mga8
+ Revision: 1651024
- ICU 68 uses standard C++ bool true
- rebuild for icu

* Wed Jul 01 2020 wally <wally> 0.1.6-4.mga8
+ Revision: 1601032
- rebuild for icu 67.1

* Sat Apr 04 2020 wally <wally> 0.1.6-3.mga8
+ Revision: 1564468
- rebuild for new icu 66.1

* Fri Feb 21 2020 umeabot <umeabot> 0.1.6-2.mga8
+ Revision: 1547800
- Mageia 8 Mass Rebuild

* Mon Feb 10 2020 daviddavid <daviddavid> 0.1.6-1.mga8
+ Revision: 1488445
- new version: 0.1.6
+ wally <wally>
- replace deprecated %%configure2_5x

* Sat Oct 05 2019 daviddavid <daviddavid> 0.1.5-2.mga8
+ Revision: 1449439
- rebuild for new icu 65.1

* Tue Jan 01 2019 luigiwalser <luigiwalser> 0.1.5-1.mga7
+ Revision: 1347914
- 0.1.5

* Sat Dec 29 2018 luigiwalser <luigiwalser> 0.1.4-6.mga7
+ Revision: 1346099
- rebuild for icu

* Sun Sep 23 2018 umeabot <umeabot> 0.1.4-5.mga7
+ Revision: 1298781
- Mageia 7 Mass Rebuild

* Mon Aug 20 2018 tv <tv> 0.1.4-4.mga7
+ Revision: 1253127
- rebuild with latest icu

* Sat Jun 09 2018 wally <wally> 0.1.4-3.mga7
+ Revision: 1235626
- fix build on aarch64
+ tv <tv>
- adjust BRs

* Fri Dec 29 2017 wally <wally> 0.1.4-2.mga7
+ Revision: 1186982
- rebuild for new icu

* Thu Nov 30 2017 mjack <mjack> 0.1.4-1.mga7
+ Revision: 1180367
- Updated to version 0.1.4

* Thu Mar 16 2017 mrambo3501 <mrambo3501> 0.1.3-3.mga6
+ Revision: 1093090
- Rebuild for icu-58.2

* Mon Sep 19 2016 tv <tv> 0.1.3-2.mga6
+ Revision: 1054223
- run testsuite
- add man pages
- do install cmx2 tools
- fix license
- use %%license

* Thu Aug 11 2016 luigiwalser <luigiwalser> 0.1.3-1.mga6
+ Revision: 1045511
- 0.1.3

* Fri May 13 2016 barjac <barjac> 0.1.2-2.mga6
+ Revision: 1015023
- Rebuild for ICU

* Fri Jan 01 2016 luigiwalser <luigiwalser> 0.1.2-1.mga6
+ Revision: 917783
- BR cppunit
- 0.1.2
- fix source URL

* Fri Dec 25 2015 tv <tv> 0.1.1-6.mga6
+ Revision: 914720
- rebuild for new boost 1.60

* Mon Sep 28 2015 daviddavid <daviddavid> 0.1.1-5.mga6
+ Revision: 884377
- fix build with boost 1.59.0 (rhbz#1258127)
- rebuild for new boost 1.59.0

* Wed Aug 26 2015 tv <tv> 0.1.1-4.mga6
+ Revision: 869832
- rebuild with gcc5

* Fri Jul 24 2015 cjw <cjw> 0.1.1-3.mga6
+ Revision: 856784
- rebuild for icu 55

* Sun Feb 01 2015 tv <tv> 0.1.1-2.mga5
+ Revision: 812972
- submit to core/release

* Sat Jan 31 2015 tv <tv> 0.1.1-1.mga5
+ Revision: 812799
- new release

* Wed Oct 15 2014 umeabot <umeabot> 0.1.0-3.mga5
+ Revision: 744665
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0.1.0-2.mga5
+ Revision: 681373
- Mageia 5 Mass Rebuild

* Thu Jul 31 2014 tv <tv> 0.1.0-1.mga5
+ Revision: 658618
- bump major
- bump major
- new release

* Sun Apr 27 2014 tv <tv> 0.0.16-1.mga5
+ Revision: 618471
- new release

* Sat Apr 05 2014 wally <wally> 0.0.14-5.mga5
+ Revision: 611899
- fix lib pkg obsoletes

* Sat Apr 05 2014 wally <wally> 0.0.14-4.mga5
+ Revision: 611869
- fix lib pkg name
- rebuild for new icu

* Mon Oct 21 2013 umeabot <umeabot> 0.0.14-3.mga4
+ Revision: 537407
- Mageia 4 Mass Rebuild

* Thu Sep 26 2013 tv <tv> 0.0.14-2.mga4
+ Revision: 486940
- rebuild for new icu
+ fwang <fwang>
- use pkgconfig style br

* Tue Aug 20 2013 tv <tv> 0.0.14-1.mga4
+ Revision: 468212
- adjust file list
- BR boost-devel
- BR icu-devel
- drop merged patch
- new release

* Sat Jan 12 2013 umeabot <umeabot> 0.0.8-6.mga3
+ Revision: 356916
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild
+ boklm <boklm>
- Update group: Graphics/Other -> Graphics/Utilities

* Sat Jan 05 2013 cjw <cjw> 0.0.8-5.mga3
+ Revision: 339227
- patch1: fix build with automake 1.13

* Tue Oct 16 2012 malo <malo> 0.0.8-4.mga3
+ Revision: 307331
- update RPM group

* Wed Jul 04 2012 dmorgan <dmorgan> 0.0.8-3.mga3
+ Revision: 267749
- Fix libs packagename

* Wed Jul 04 2012 dmorgan <dmorgan> 0.0.8-2.mga3
+ Revision: 267742
- Fix provides in the devel package

* Wed Jul 04 2012 dmorgan <dmorgan> 0.0.8-1.mga3
+ Revision: 267737
- Fix configure
- imported package libcdr


* Mon Jun 11 2012 David Tardon <dtardon@redhat.com> 0.0.8-1
- new upstream release
- adds basic initial primitive uncomplete text support

* Thu Apr 26 2012 David Tardon <dtardon@redhat.com> 0.0.7-1
- new upstream release

* Tue Apr 03 2012 David Tardon <dtardon@redhat.com> 0.0.6-1
- new upstream release

* Mon Mar 19 2012 David Tardon <dtardon@redhat.com> 0.0.5-1
- new upstream release
- fix license

* Sat Mar 10 2012 David Tardon <dtardon@redhat.com> 0.0.3-2
- remove Requires: of main package from -doc subpackage

* Thu Mar 01 2012 David Tardon <dtardon@redhat.com> 0.0.3-1
- initial import
